@@ -11,7 +11,9 @@ import (
 
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
+	adminv1 "github.com/acorn-io/acorn/pkg/apis/internal.admin.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/client"
+	"github.com/acorn-io/acorn/pkg/config"
 	"github.com/acorn-io/acorn/pkg/controller"
 	"github.com/acorn-io/acorn/pkg/crds"
 	hclient "github.com/acorn-io/acorn/pkg/k8sclient"
@@ -48,7 +50,10 @@ func EnsureCRDs(t *testing.T) {
 	t.Helper()
 
 	ctx := GetCTX(t)
-	if err := crds.Create(ctx, scheme.Scheme, v1.SchemeGroupVersion); err != nil {
+	if err := crds.Create(ctx, scheme.Scheme, v1.SchemeGroupVersion, adminv1.SchemeGroupVersion); err != nil {
+		t.Fatal(err)
+	}
+	if err := crds.Create(ctx, scheme.Scheme, adminv1.SchemeGroupVersion); err != nil {
 		t.Fatal(err)
 	}
 	c, err := hclient.Default()
@@ -84,6 +89,7 @@ func BuilderClient(t *testing.T, namespace string) client.Client {
 	if err != nil {
 		t.Fatal(err)
 	}
+
 	return c
 }
 
@@ -215,6 +221,20 @@ func StartController(t *testing.T) {
 			t.Fatal(err)
 		}
 
+		cfg, err := config.Get(ctx, c.Router.Backend())
+		if err != nil {
+			t.Fatal(err)
+		}
+
+		if *cfg.BuilderPerProject {
+			err = config.Set(ctx, c.Router.Backend(), &apiv1.Config{
+				BuilderPerProject: new(bool),
+			})
+			if err != nil {
+				t.Fatal(err)
+			}
+		}
+
 		if err := c.Start(context.Background()); err != nil {
 			t.Fatal(err)
 		}
