@@ -3,6 +3,7 @@
 package v1
 
 import (
+	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -10,6 +11,8 @@ type AppInstanceCondition string
 
 var (
 	AppInstanceConditionDefined    = "defined"
+	AppInstanceConditionDefaults   = "defaults"
+	AppInstanceConditionScheduling = "scheduling"
 	AppInstanceConditionNamespace  = "namespace"
 	AppInstanceConditionParsed     = "parsed"
 	AppInstanceConditionController = "controller"
@@ -19,6 +22,7 @@ var (
 	AppInstanceConditionJobs       = "jobs"
 	AppInstanceConditionReady      = "Ready"
 	AppInstanceConditionUpgrade    = "upgrade"
+	AppInstanceConditionVolumes    = "volumes"
 )
 
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
@@ -73,7 +77,8 @@ type AppInstanceSpec struct {
 	AutoUpgrade         *bool            `json:"autoUpgrade,omitempty"`
 	NotifyUpgrade       *bool            `json:"notifyUpgrade,omitempty"`
 	AutoUpgradeInterval string           `json:"autoUpgradeInterval,omitempty"`
-	Memory              Memory           `json:"memory,omitempty"`
+	ComputeClass        ComputeClassMap  `json:"computeClass,omitempty"`
+	Memory              MemoryMap        `json:"memory,omitempty"`
 }
 
 func (in *AppInstanceSpec) GetAutoUpgrade() bool {
@@ -159,8 +164,27 @@ type AppInstanceStatus struct {
 	AvailableAppImage      string                     `json:"availableAppImage,omitempty"`
 	ConfirmUpgradeAppImage string                     `json:"confirmUpgradeAppImage,omitempty"`
 	AppSpec                AppSpec                    `json:"appSpec,omitempty"`
+	Scheduling             map[string]Scheduling      `json:"scheduling,omitempty"`
 	Conditions             []Condition                `json:"conditions,omitempty"`
 	Endpoints              []Endpoint                 `json:"endpoints,omitempty"`
+	Defaults               Defaults                   `json:"defaults,omitempty"`
+}
+
+type Defaults struct {
+	Volumes map[string]VolumeDefault `json:"volumes,omitempty"`
+	Memory  map[string]*int64        `json:"memory,omitempty"`
+}
+
+type VolumeDefault struct {
+	Class       string      `json:"class,omitempty"`
+	Size        Quantity    `json:"size,omitempty"`
+	AccessModes AccessModes `json:"accessModes,omitempty"`
+}
+
+type Scheduling struct {
+	Requirements corev1.ResourceRequirements `json:"requirements,omitempty"`
+	Affinity     *corev1.Affinity            `json:"affinity,omitempty"`
+	Tolerations  []corev1.Toleration         `json:"tolerations,omitempty"`
 }
 
 type Endpoint struct {
