@@ -135,22 +135,23 @@ func (in *Dependencies) UnmarshalJSON(data []byte) error {
 }
 
 func (in *Quantity) UnmarshalJSON(data []byte) error {
+	var (
+		s   string
+		err error
+	)
 	if !isString(data) {
-		var s int
-		if err := json.Unmarshal(data, &s); err != nil {
+		var d int
+		if err = json.Unmarshal(data, &d); err != nil {
 			return err
 		}
-		if s < 1000000 {
-			*in = (Quantity)(fmt.Sprintf("%dG", s))
-		} else {
-			*in = (Quantity)(fmt.Sprintf("%d", s))
+		s = fmt.Sprintf("%d", d)
+	} else {
+		s, err = parseString(data)
+		if err != nil {
+			return err
 		}
-		return nil
-	}
-	s, err := parseString(data)
-	if err != nil {
-		return err
 	}
+
 	q, err := ParseQuantity(s)
 	if err != nil {
 		return err
@@ -257,13 +258,15 @@ func impliedVolumesForContainer(app *AppSpec, containerName, sideCarName string,
 					// ignore error
 					continue
 				}
-				vSize, err := resource.ParseQuantity((string)(v.Size))
-				if err != nil {
-					// ignore error
-					continue
-				}
-				if existingSize.Cmp(vSize) < 0 {
-					existing.Size = v.Size
+				if v.Size != "" {
+					vSize, err := resource.ParseQuantity((string)(v.Size))
+					if err != nil {
+						// ignore error
+						continue
+					}
+					if existingSize.Cmp(vSize) < 0 {
+						existing.Size = v.Size
+					}
 				}
 				for _, accessMode := range v.AccessModes {
 					found := false
@@ -282,6 +285,9 @@ func impliedVolumesForContainer(app *AppSpec, containerName, sideCarName string,
 				})
 				app.Volumes[mount.Volume] = existing
 			} else {
+				if v.Size == "" {
+					v.Size = DefaultSizeQuantity
+				}
 				app.Volumes[mount.Volume] = VolumeRequest{
 					Size:        v.Size,
 					AccessModes: v.AccessModes,
@@ -289,10 +295,7 @@ func impliedVolumesForContainer(app *AppSpec, containerName, sideCarName string,
 				}
 			}
 		} else if _, ok := app.Volumes[mount.Volume]; !ok {
-			app.Volumes[mount.Volume] = VolumeRequest{
-				Size:        DefaultSizeQuantity,
-				AccessModes: []AccessMode{AccessModeReadWriteOnce},
-			}
+			app.Volumes[mount.Volume] = VolumeRequest{}
 		}
 	}
 	return nil
@@ -1098,8 +1101,6 @@ func parseVolumeDefinition(anonName, s string) (VolumeBinding, error) {
 		if result.Volume == "" {
 			result.Volume = anonName
 		}
-	} else if result.Size == "" {
-		result.Size = DefaultSizeQuantity
 	}
 
 	for _, accessMode := range u.Query()["accessMode"] {
@@ -1110,10 +1111,6 @@ func parseVolumeDefinition(anonName, s string) (VolumeBinding, error) {
 		result.AccessModes = append(result.AccessModes, AccessMode(accessMode))
 	}
 
-	if len(result.AccessModes) == 0 {
-		result.AccessModes = AccessModes{AccessModeReadWriteOnce}
-	}
-
 	return result, nil
 }
 
@@ -1153,9 +1150,12 @@ func ParseQuantity(s string) (Quantity, error) {
 	if s == "" {
 		return "", nil
 	}
-	_, err := strconv.Atoi(s)
+	d, err := strconv.Atoi(s)
 	if err == nil {
-		return (Quantity)(s + "G"), nil
+		if d < 1000000 {
+			s += "G"
+		}
+		return Quantity(s), nil
 	}
 
 	_, err = resource.ParseQuantity(s)
@@ -1163,7 +1163,7 @@ func ParseQuantity(s string) (Quantity, error) {
 		return "", err
 	}
 
-	return (Quantity)(s), nil
+	return Quantity(s), nil
 }
 
 func ParseNameValues(fillEnv bool, s ...string) (result []NameValue) {
