@@ -1246,17 +1246,17 @@ volumes: {
 	assert.Equal(t, "cclass", appSpec.Volumes["v21"].Class)
 	assert.Equal(t, toQuantity(21), appSpec.Volumes["v21"].Size)
 	assert.Equal(t, "", appSpec.Volumes["short-implicit"].Class)
-	assert.Equal(t, toQuantity(10), appSpec.Volumes["short-implicit"].Size)
-	assert.Equal(t, toQuantity(10), appSpec.Volumes["ephemeral"].Size)
+	assert.Equal(t, v1.Quantity(""), appSpec.Volumes["short-implicit"].Size)
+	assert.Equal(t, v1.Quantity(""), appSpec.Volumes["ephemeral"].Size)
 	assert.Equal(t, "", appSpec.Volumes["defaults"].Class)
-	assert.Equal(t, toQuantity(10), appSpec.Volumes["defaults"].Size)
-	assert.Equal(t, v1.AccessModes{v1.AccessModeReadWriteOnce}, appSpec.Volumes["defaults"].AccessModes)
+	assert.Equal(t, v1.Quantity(""), appSpec.Volumes["defaults"].Size)
+	assert.Nil(t, appSpec.Volumes["defaults"].AccessModes)
 	// class not supported
 	assert.Equal(t, "", appSpec.Volumes["uri"].Class)
 	assert.Equal(t, toQuantity(70), appSpec.Volumes["uri"].Size)
 	assert.Equal(t, v1.AccessModes{"readWriteMany", "readWriteOnce"}, appSpec.Volumes["uri"].AccessModes)
 	assert.Equal(t, toQuantity(10), appSpec.Volumes["uri-sub"].Size)
-	assert.Equal(t, v1.AccessModes{"readWriteOnce"}, appSpec.Volumes["uri-sub"].AccessModes)
+	assert.Nil(t, appSpec.Volumes["uri-sub"].AccessModes)
 	assert.Equal(t, "ephemeral", appSpec.Volumes["s/left/var/anon-ephemeral-vol"].Class)
 	assert.Equal(t, "ephemeral", appSpec.Volumes["s/left/var/anon-ephemeral2-vol"].Class)
 	assert.Equal(t, "ephemeral", appSpec.Volumes["eph"].Class)
@@ -1899,23 +1899,6 @@ let foo = std.toyaml({})
 	assert.Contains(t, err.Error(), "invalid reference to std.toyaml, closest matches [toYAML fromYAML trim]")
 }
 
-func TestStd(t *testing.T) {
-	data, err := os.ReadFile("std_test.cue")
-	if err != nil {
-		t.Fatal(err)
-	}
-
-	def, err := NewAppDefinition(data)
-	if err != nil {
-		t.Fatal(err)
-	}
-
-	_, err = def.AppSpec()
-	if err != nil {
-		t.Fatal(err)
-	}
-}
-
 func TestArgsTopCondition(t *testing.T) {
 	data := `
 let foo = true
