@@ -8,6 +8,8 @@ import (
 
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
 	"github.com/acorn-io/acorn/pkg/client/term"
+	"github.com/acorn-io/acorn/pkg/config"
+	"github.com/acorn-io/acorn/pkg/project"
 	"github.com/google/go-containerregistry/pkg/logs"
 	"github.com/pterm/pterm"
 	"github.com/sirupsen/logrus"
@@ -46,6 +48,7 @@ func New() *cobra.Command {
 		NewExec(cmdContext),
 		NewImage(cmdContext),
 		NewInstall(cmdContext),
+		NewOfferings(cmdContext),
 		NewUninstall(cmdContext),
 		NewInfo(cmdContext),
 		NewLogs(cmdContext),
@@ -117,6 +120,23 @@ func (a *Acorn) PersistentPre(cmd *cobra.Command, args []string) error {
 			return err
 		}
 	}
+
+	if a.Project != "" {
+		clientFactory := CommandClientFactory{
+			cmd:   cmd,
+			acorn: a,
+		}
+		cfg, err := config.ReadCLIConfig()
+		if err != nil {
+			return err
+		}
+
+		err = project.Exists(cmd.Context(), clientFactory.Options().WithCLIConfig(cfg), a.Project)
+		if err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
