@@ -8,6 +8,7 @@ import (
 	"time"
 
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
+	adminv1 "github.com/acorn-io/acorn/pkg/apis/internal.admin.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/tags"
 	"github.com/rancher/wrangler/pkg/data/convert"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -34,6 +35,9 @@ var (
 		"trunc":         Trunc,
 		"alias":         Noop,
 		"appGeneration": AppGeneration,
+		"displayRange":  DisplayRange,
+		"memoryToRange": MemoryToRange,
+		"defaultMemory": DefaultMemory,
 	}
 )
 
@@ -60,6 +64,10 @@ func ToArray(s []string) (string, error) {
 	return strings.Join(s, ", "), nil
 }
 
+func ToArrayNoSpace(s []string) (string, error) {
+	return strings.Join(s, ","), nil
+}
+
 func ToArrayFirst(s []string) (string, error) {
 	if len(s) > 0 {
 		return s[0], nil
@@ -176,6 +184,64 @@ func BoolToStar(obj any) (string, error) {
 	return "", nil
 }
 
+func DisplayRange(minVal, maxVal any) (string, error) {
+	min, max := fmt.Sprintf("%v", minVal), fmt.Sprintf("%v", maxVal)
+	if max == "" {
+		max = "Unrestricted"
+	}
+	if min == "" {
+		if max == "Unrestricted" {
+			return max, nil
+		}
+		min = "5M"
+	}
+
+	return fmt.Sprintf("%s-%s", min, max), nil
+}
+
+func DefaultMemory(obj any) (string, error) {
+	b, ok := obj.(adminv1.ComputeClassMemory)
+	if !ok {
+		return "", fmt.Errorf("object passed is not a ComputeClassMemory struct")
+	}
+
+	result := b.Default
+	if b.Default == "0" || b.Default == "" {
+		result = b.Max
+		if result == "0" || result == "" {
+			result = "Unrestricted"
+		}
+	}
+	return result, nil
+}
+
+func MemoryToRange(obj any) (string, error) {
+	b, ok := obj.(adminv1.ComputeClassMemory)
+	if !ok {
+		return "", fmt.Errorf("object passed is not a ComputeClassMemory struct")
+	}
+
+	min := b.Min
+	if min == "" {
+		min = "0"
+	}
+
+	max := b.Max
+	if max == "" || max == "0" {
+		max = "Unrestricted"
+	}
+
+	if len(b.Values) != 0 {
+		return strings.Join(b.Values, ","), nil
+	}
+
+	if max == "Unrestricted" && min == "0" {
+		return "Unrestricted", nil
+	}
+
+	return fmt.Sprintf("%v-%v", min, max), nil
+}
+
 func AppGeneration(app apiv1.App, msg string) string {
 	if app.Generation != app.Status.ObservedGeneration {
 		return "[controller: not processed] " + msg
