@@ -20,7 +20,7 @@ type Controller struct {
 	client ClientFactory
 }
 
-func (s *Controller) Run(cmd *cobra.Command, args []string) error {
+func (s *Controller) Run(cmd *cobra.Command, _ []string) error {
 	c, err := controller.New()
 	if err != nil {
 		return err
