@@ -28,7 +28,7 @@ func NewExec(c CommandContext) *cobra.Command {
 
 	// This will produce an error if the container flag doesn't exist or a completion function has already
 	// been registered for this flag. Not returning the error since neither of these is likely occur.
-	if err := cmd.RegisterFlagCompletionFunc("container", newCompletion(c.ClientFactory, acornContainerCompletion).withShouldCompleteOptions(onlyNumArgs(1)).complete); err != nil {
+	if err := cmd.RegisterFlagCompletionFunc("container", newCompletion(c.ClientFactory, acornContainerCompletion).complete); err != nil {
 		cmd.Printf("Error registering completion function for -c flag: %v\n", err)
 	}
 
@@ -43,7 +43,7 @@ type Exec struct {
 	client      ClientFactory
 }
 
-func (s *Exec) appAndArgs(ctx context.Context, c client.Client, args []string) (string, []string, error) {
+func appAndArgs(ctx context.Context, c client.Client, args []string) (string, []string, error) {
 	if len(args) > 0 {
 		return args[0], args[1:], nil
 	}
@@ -161,11 +161,7 @@ func (s *Exec) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	if s.DebugImage != "" && len(args) == 0 {
-		return s.execContainer(ctx, c, "_", nil)
-	}
-
-	name, args, err := s.appAndArgs(ctx, c, args)
+	name, args, err := appAndArgs(ctx, c, args)
 	if err != nil {
 		return err
 	}
