@@ -9,8 +9,8 @@ import (
 	"github.com/spf13/pflag"
 )
 
-func NewRender() *cobra.Command {
-	cmd := cli.Command(&Render{}, cobra.Command{
+func NewRender(c CommandContext) *cobra.Command {
+	cmd := cli.Command(&Render{client: c.ClientFactory}, cobra.Command{
 		Use:          "render [flags] DIRECTORY [acorn args]",
 		SilenceUsage: true,
 		Short:        "Evaluate and display an Acornfile with args",
@@ -24,6 +24,7 @@ type Render struct {
 	File    string   `short:"f" usage:"Name of the dev file" default:"DIRECTORY/Acornfile"`
 	Profile []string `usage:"Profile to assign default values"`
 	Output  string   `usage:"Output in JSON or YAML" default:"json" short:"o"`
+	client  ClientFactory
 }
 
 func (s *Render) Run(cmd *cobra.Command, args []string) error {
