@@ -10,23 +10,43 @@ import (
 	"github.com/acorn-io/acorn/pkg/client"
 	"github.com/acorn-io/acorn/pkg/client/term"
 	"github.com/acorn-io/acorn/pkg/project"
+	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime/schema"
 	kclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
+type MockClientFactoryManual struct {
+	Client client.Client
+}
+
+func (dc *MockClientFactoryManual) Options() project.Options {
+	return project.Options{}
+}
+
+func (dc *MockClientFactoryManual) CreateDefault() (client.Client, error) {
+	return dc.Client, nil
+}
+
 type MockClientFactory struct {
-	AppList        []apiv1.App
-	AppItem        *apiv1.App
-	ContainerList  []apiv1.ContainerReplica
-	ContainerItem  *apiv1.ContainerReplica
-	CredentialList []apiv1.Credential
-	CredentialItem *apiv1.Credential
-	VolumeList     []apiv1.Volume
-	VolumeItem     *apiv1.Volume
-	SecretList     []apiv1.Secret
-	SecretItem     *apiv1.Secret
-	ImageList      []apiv1.Image
-	ImageItem      *apiv1.Image
+	AppList          []apiv1.App
+	AppItem          *apiv1.App
+	ContainerList    []apiv1.ContainerReplica
+	ContainerItem    *apiv1.ContainerReplica
+	CredentialList   []apiv1.Credential
+	CredentialItem   *apiv1.Credential
+	VolumeList       []apiv1.Volume
+	VolumeItem       *apiv1.Volume
+	SecretList       []apiv1.Secret
+	SecretItem       *apiv1.Secret
+	ImageList        []apiv1.Image
+	ImageItem        *apiv1.Image
+	ProjectList      []apiv1.Project
+	ProjectItem      *apiv1.Project
+	VolumeClassList  []apiv1.VolumeClass
+	VolumeClassItem  *apiv1.VolumeClass
+	ComputeClassList []apiv1.ComputeClass
+	ComputeClassItem *apiv1.ComputeClass
 }
 
 func (dc *MockClientFactory) Options() project.Options {
@@ -35,34 +55,46 @@ func (dc *MockClientFactory) Options() project.Options {
 
 func (dc *MockClientFactory) CreateDefault() (client.Client, error) {
 	return &MockClient{
-		Apps:           dc.AppList,
-		Containers:     dc.ContainerList,
-		Credentials:    dc.CredentialList,
-		Volumes:        dc.VolumeList,
-		Secrets:        dc.SecretList,
-		Images:         dc.ImageList,
-		AppItem:        dc.AppItem,
-		ContainerItem:  dc.ContainerItem,
-		CredentialItem: dc.CredentialItem,
-		VolumeItem:     dc.VolumeItem,
-		SecretItem:     dc.SecretItem,
-		ImageItem:      dc.ImageItem,
+		Apps:             dc.AppList,
+		Containers:       dc.ContainerList,
+		Credentials:      dc.CredentialList,
+		Volumes:          dc.VolumeList,
+		Secrets:          dc.SecretList,
+		Images:           dc.ImageList,
+		Projects:         dc.ProjectList,
+		VolumeClasses:    dc.VolumeClassList,
+		AppItem:          dc.AppItem,
+		ContainerItem:    dc.ContainerItem,
+		CredentialItem:   dc.CredentialItem,
+		VolumeItem:       dc.VolumeItem,
+		SecretItem:       dc.SecretItem,
+		ImageItem:        dc.ImageItem,
+		ProjectItem:      dc.ProjectItem,
+		VolumeClassItem:  dc.VolumeClassItem,
+		ComputeClasses:   dc.ComputeClassList,
+		ComputeClassItem: dc.ComputeClassItem,
 	}, nil
 }
 
 type MockClient struct {
-	Apps           []apiv1.App
-	AppItem        *apiv1.App
-	Containers     []apiv1.ContainerReplica
-	ContainerItem  *apiv1.ContainerReplica
-	Credentials    []apiv1.Credential
-	CredentialItem *apiv1.Credential
-	Volumes        []apiv1.Volume
-	VolumeItem     *apiv1.Volume
-	Secrets        []apiv1.Secret
-	SecretItem     *apiv1.Secret
-	Images         []apiv1.Image
-	ImageItem      *apiv1.Image
+	Apps             []apiv1.App
+	AppItem          *apiv1.App
+	Containers       []apiv1.ContainerReplica
+	ContainerItem    *apiv1.ContainerReplica
+	Credentials      []apiv1.Credential
+	CredentialItem   *apiv1.Credential
+	Volumes          []apiv1.Volume
+	VolumeItem       *apiv1.Volume
+	Secrets          []apiv1.Secret
+	SecretItem       *apiv1.Secret
+	Images           []apiv1.Image
+	ImageItem        *apiv1.Image
+	Projects         []apiv1.Project
+	ProjectItem      *apiv1.Project
+	VolumeClasses    []apiv1.VolumeClass
+	VolumeClassItem  *apiv1.VolumeClass
+	ComputeClasses   []apiv1.ComputeClass
+	ComputeClassItem *apiv1.ComputeClass
 }
 
 func (m *MockClient) AppPullImage(ctx context.Context, name string) error {
@@ -571,11 +603,13 @@ func (m *MockClient) BuilderRegistryDialer(ctx context.Context) (func(ctx contex
 	return nil, nil
 }
 
-func (m *MockClient) Info(ctx context.Context) (*apiv1.Info, error) {
-	return &apiv1.Info{
-		TypeMeta:   metav1.TypeMeta{},
-		ObjectMeta: metav1.ObjectMeta{},
-		Spec:       apiv1.InfoSpec{},
+func (m *MockClient) Info(ctx context.Context) ([]apiv1.Info, error) {
+	return []apiv1.Info{
+		{
+			TypeMeta:   metav1.TypeMeta{},
+			ObjectMeta: metav1.ObjectMeta{},
+			Spec:       apiv1.InfoSpec{},
+		},
 	}, nil
 }
 
@@ -592,46 +626,97 @@ func (m *MockClient) AppConfirmUpgrade(ctx context.Context, name string) error {
 }
 
 func (m *MockClient) AcornImageBuildGet(ctx context.Context, name string) (*apiv1.AcornImageBuild, error) {
-	//TODO implement me
+	// TODO implement me
 	panic("implement me")
 }
 
 func (m *MockClient) AcornImageBuildList(ctx context.Context) ([]apiv1.AcornImageBuild, error) {
-	//TODO implement me
+	// TODO implement me
 	panic("implement me")
 }
 
 func (m *MockClient) AcornImageBuildDelete(ctx context.Context, name string) (*apiv1.AcornImageBuild, error) {
-	//TODO implement me
+	// TODO implement me
 	panic("implement me")
 }
 
 func (m *MockClient) AcornImageBuild(ctx context.Context, file string, opts *client.AcornImageBuildOptions) (*v1.AppImage, error) {
-	//TODO implement me
+	// TODO implement me
 	panic("implement me")
 }
 
 func (m *MockClient) ProjectList(ctx context.Context) ([]apiv1.Project, error) {
-	//TODO implement me
-	panic("implement me")
+	if m.Projects != nil {
+		return m.Projects, nil
+	}
+	return []apiv1.Project{{
+		TypeMeta:   metav1.TypeMeta{},
+		ObjectMeta: metav1.ObjectMeta{Name: "project"},
+	}}, nil
+}
+
+func (m *MockClient) ComputeClassList(_ context.Context) ([]apiv1.ComputeClass, error) {
+	return m.ComputeClasses, nil
+}
+
+func (m *MockClient) ComputeClassGet(_ context.Context, name string) (*apiv1.ComputeClass, error) {
+	if m.ComputeClassItem != nil {
+		return m.ComputeClassItem, nil
+	}
+
+	for _, s := range m.ComputeClasses {
+		if s.Name == name {
+			return &s, nil
+		}
+	}
+
+	return nil, apierrors.NewNotFound(schema.GroupResource{
+		Group:    "api.acorn.io",
+		Resource: "computeclasses",
+	}, name)
 }
 
 func (m *MockClient) GetProject() string {
-	//TODO implement me
-	panic("implement me")
+	if m.ProjectItem != nil {
+		return m.ProjectItem.Name
+	}
+	return ""
 }
 
 func (m *MockClient) ProjectGet(ctx context.Context, name string) (*apiv1.Project, error) {
-	//TODO implement me
-	panic("implement me")
+	if m.ProjectItem != nil {
+		return m.ProjectItem, nil
+	}
+	return nil, nil
 }
 
 func (m *MockClient) ProjectCreate(ctx context.Context, name string) (*apiv1.Project, error) {
-	//TODO implement me
+	// TODO implement me
 	panic("implement me")
 }
 
 func (m *MockClient) ProjectDelete(ctx context.Context, name string) (*apiv1.Project, error) {
-	//TODO implement me
+	// TODO implement me
 	panic("implement me")
 }
+
+func (m *MockClient) VolumeClassList(context.Context) ([]apiv1.VolumeClass, error) {
+	return m.VolumeClasses, nil
+}
+
+func (m *MockClient) VolumeClassGet(_ context.Context, name string) (*apiv1.VolumeClass, error) {
+	if m.VolumeClassItem != nil {
+		return m.VolumeClassItem, nil
+	}
+
+	for _, s := range m.VolumeClasses {
+		if s.Name == name {
+			return &s, nil
+		}
+	}
+
+	return nil, apierrors.NewNotFound(schema.GroupResource{
+		Group:    "api.acorn.io",
+		Resource: "volumeclasses",
+	}, name)
+}
