@@ -59,6 +59,7 @@ func ToApp(namespace, image string, opts *AppRunOptions) *apiv1.App {
 			NotifyUpgrade:       opts.NotifyUpgrade,
 			AutoUpgradeInterval: opts.AutoUpgradeInterval,
 			Memory:              opts.Memory,
+			ComputeClass:        opts.ComputeClass,
 		},
 	}
 }
@@ -141,6 +142,9 @@ func ToAppUpdate(ctx context.Context, c Client, name string, opts *AppUpdateOpti
 	if len(opts.Memory) != 0 {
 		app.Spec.Memory = opts.Memory
 	}
+	if len(opts.ComputeClass) != 0 {
+		app.Spec.ComputeClass = opts.ComputeClass
+	}
 
 	return app, nil
 }
@@ -433,9 +437,7 @@ func (c *DefaultClient) appStop(ctx context.Context, name string) error {
 		Name:      name,
 		Namespace: c.Namespace,
 	}, app)
-	if apierrors.IsNotFound(err) {
-		return nil
-	} else if err != nil {
+	if err != nil {
 		return err
 	}
 	if app.Spec.Stop == nil || !*app.Spec.Stop {
