@@ -95,7 +95,8 @@ type AppUpdateOptions struct {
 	AutoUpgrade         *bool
 	NotifyUpgrade       *bool
 	AutoUpgradeInterval string
-	Memory              v1.Memory
+	Memory              v1.MemoryMap
+	ComputeClass        v1.ComputeClassMap
 }
 
 type LogOptions apiv1.LogOptions
@@ -118,7 +119,8 @@ type AppRunOptions struct {
 	AutoUpgrade         *bool
 	NotifyUpgrade       *bool
 	AutoUpgradeInterval string
-	Memory              v1.Memory
+	Memory              v1.MemoryMap
+	ComputeClass        v1.ComputeClassMap
 }
 
 func (a AppRunOptions) ToUpdate() AppUpdateOptions {
@@ -140,6 +142,7 @@ func (a AppRunOptions) ToUpdate() AppUpdateOptions {
 		NotifyUpgrade:       a.NotifyUpgrade,
 		AutoUpgradeInterval: a.AutoUpgradeInterval,
 		Memory:              a.Memory,
+		ComputeClass:        a.ComputeClass,
 	}
 }
 
@@ -162,6 +165,7 @@ func (a AppUpdateOptions) ToRun() AppRunOptions {
 		NotifyUpgrade:       a.NotifyUpgrade,
 		AutoUpgradeInterval: a.AutoUpgradeInterval,
 		Memory:              a.Memory,
+		ComputeClass:        a.ComputeClass,
 	}
 }
 
@@ -230,7 +234,13 @@ type Client interface {
 	ProjectCreate(ctx context.Context, name string) (*apiv1.Project, error)
 	ProjectDelete(ctx context.Context, name string) (*apiv1.Project, error)
 
-	Info(ctx context.Context) (*apiv1.Info, error)
+	VolumeClassList(ctx context.Context) ([]apiv1.VolumeClass, error)
+	VolumeClassGet(ctx context.Context, name string) (*apiv1.VolumeClass, error)
+
+	Info(ctx context.Context) ([]apiv1.Info, error)
+
+	ComputeClassList(ctx context.Context) ([]apiv1.ComputeClass, error)
+	ComputeClassGet(ctx context.Context, name string) (*apiv1.ComputeClass, error)
 
 	GetProject() string
 	GetNamespace() string
