@@ -12,6 +12,7 @@ import (
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/condition"
 	"github.com/acorn-io/acorn/pkg/config"
+	"github.com/acorn-io/acorn/pkg/expose"
 	"github.com/acorn-io/acorn/pkg/images"
 	"github.com/acorn-io/acorn/pkg/labels"
 	"github.com/acorn-io/acorn/pkg/ports"
@@ -186,7 +187,7 @@ func hasContextDir(container v1.Container) bool {
 	return false
 }
 
-func toContainers(req router.Request, app *v1.AppInstance, tag name.Reference, name string, container v1.Container) ([]corev1.Container, []corev1.Container, error) {
+func toContainers(req router.Request, app *v1.AppInstance, tag name.Reference, name string, container v1.Container) ([]corev1.Container, []corev1.Container) {
 	var (
 		containers     []corev1.Container
 		initContainers []corev1.Container
@@ -207,17 +208,10 @@ func toContainers(req router.Request, app *v1.AppInstance, tag name.Reference, n
 		})
 	}
 
-	newContainer, err := toContainer(req, app, tag, name, name, container)
-	if err != nil {
-		return nil, nil, err
-	}
-
+	newContainer := toContainer(req, app, tag, name, name, container)
 	containers = append(containers, newContainer)
 	for _, entry := range typed.Sorted(container.Sidecars) {
-		newContainer, err = toContainer(req, app, tag, name, entry.Key, entry.Value)
-		if err != nil {
-			return nil, nil, err
-		}
+		newContainer = toContainer(req, app, tag, name, entry.Key, entry.Value)
 
 		if entry.Value.Init {
 			initContainers = append(initContainers, newContainer)
@@ -226,7 +220,7 @@ func toContainers(req router.Request, app *v1.AppInstance, tag name.Reference, n
 		}
 	}
 
-	return containers, initContainers, nil
+	return containers, initContainers
 }
 
 func pathHash(parts ...string) string {
@@ -410,7 +404,7 @@ func toProbe(container v1.Container, probeType v1.ProbeType) *corev1.Probe {
 	return nil
 }
 
-func toContainer(req router.Request, app *v1.AppInstance, tag name.Reference, deploymentName, containerName string, container v1.Container) (corev1.Container, error) {
+func toContainer(req router.Request, app *v1.AppInstance, tag name.Reference, deploymentName, containerName string, container v1.Container) corev1.Container {
 	containerObject := corev1.Container{
 		Name:           containerName,
 		Image:          images.ResolveTag(tag, container.Image),
@@ -426,27 +420,10 @@ func toContainer(req router.Request, app *v1.AppInstance, tag name.Reference, de
 		LivenessProbe:  toProbe(container, v1.LivenessProbeType),
 		StartupProbe:   toProbe(container, v1.StartupProbeType),
 		ReadinessProbe: toProbe(container, v1.ReadinessProbeType),
+		Resources:      app.Status.Scheduling[containerName].Requirements,
 	}
 
-	resources, err := toResources(req, app, container, containerName)
-	if err != nil {
-		return corev1.Container{}, err
-	}
-
-	if resources != nil {
-		containerObject.Resources = *resources
-	}
-
-	return containerObject, err
-}
-
-func toResources(req router.Request, app *v1.AppInstance, container v1.Container, containerName string) (*corev1.ResourceRequirements, error) {
-	cfg, err := config.Get(req.Ctx, req.Client)
-	if err != nil {
-		return nil, err
-	}
-
-	return v1.MemoryToRequirements(app.Spec.Memory, containerName, container, cfg.WorkloadMemoryDefault, cfg.WorkloadMemoryMaximum)
+	return containerObject
 }
 
 func containerAnnotations(appInstance *v1.AppInstance, container v1.Container, name string) map[string]string {
@@ -608,10 +585,7 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 		stateful = isStateful(appInstance, container)
 	)
 
-	containers, initContainers, err := toContainers(req, appInstance, tag, name, container)
-	if err != nil {
-		return nil, err
-	}
+	containers, initContainers := toContainers(req, appInstance, tag, name, container)
 
 	secretAnnotations, err := getSecretAnnotations(req, appInstance, container)
 	if err != nil {
@@ -648,6 +622,8 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 					Annotations: typed.Concat(deploymentAnnotations, podAnnotations(appInstance, name, container), secretAnnotations),
 				},
 				Spec: corev1.PodSpec{
+					Affinity:                      appInstance.Status.Scheduling[name].Affinity,
+					Tolerations:                   appInstance.Status.Scheduling[name].Tolerations,
 					TerminationGracePeriodSeconds: &[]int64{5}[0],
 					ImagePullSecrets:              pullSecrets.ForContainer(name, append(containers, initContainers...)),
 					EnableServiceLinks:            new(bool),
@@ -688,7 +664,7 @@ func ToDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Ref
 		if perms := v1.FindPermission(dep.GetName(), appInstance.Spec.Permissions); perms.HasRules() {
 			result = append(result, toPermissions(perms, dep.GetLabels(), dep.GetAnnotations(), appInstance)...)
 		}
-		result = append(result, dep, sa)
+		result = append(result, dep, sa, expose.ToPodDisruptionBudget(dep))
 	}
 	return result, nil
 }
