@@ -5,6 +5,7 @@ import (
 	"time"
 
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
+	adminv1 "github.com/acorn-io/acorn/pkg/apis/internal.admin.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/autoupgrade"
 	"github.com/acorn-io/acorn/pkg/config"
 	"github.com/acorn-io/acorn/pkg/crds"
@@ -16,7 +17,6 @@ import (
 	"github.com/acorn-io/baaah/pkg/apply"
 	"github.com/acorn-io/baaah/pkg/restconfig"
 	"github.com/acorn-io/baaah/pkg/router"
-	"github.com/sirupsen/logrus"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"sigs.k8s.io/controller-runtime/pkg/client"
@@ -70,6 +70,9 @@ func (c *Controller) Start(ctx context.Context) error {
 	if err := crds.Create(ctx, c.Scheme, v1.SchemeGroupVersion); err != nil {
 		return err
 	}
+	if err := crds.Create(ctx, c.Scheme, adminv1.SchemeGroupVersion); err != nil {
+		return err
+	}
 	if err := c.initData(ctx); err != nil {
 		return err
 	}
@@ -91,10 +94,7 @@ func (c *Controller) Start(ctx context.Context) error {
 		dnsInit := dns.NewDaemon(c.Router.Backend())
 		go wait.UntilWithContext(ctx, dnsInit.RenewAndSync, dnsRenewPeriodHours)
 
-		err := autoupgrade.StartSync(ctx, c.Router.Backend())
-		if err != nil {
-			logrus.Errorf("auto-upgrade daemon exited with error: %v", err)
-		}
+		autoupgrade.StartSync(ctx, c.Router.Backend())
 	}()
 
 	return c.Router.Start(ctx)
