@@ -16,6 +16,7 @@ import (
 	name2 "github.com/rancher/wrangler/pkg/name"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
+	policyv1 "k8s.io/api/policy/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -50,7 +51,7 @@ func Acorns(req router.Request, app *v1.AppInstance) (result []kclient.Object, _
 		dsSvc := toRouterDeploymentService(service, app, ds, ports)
 		svc := toService(cfg, service, app, dsSvc)
 
-		result = append(result, ds, dsSvc, svc)
+		result = append(result, ds, dsSvc, svc, ToPodDisruptionBudget(ds))
 	}
 
 	return result, nil
@@ -91,13 +92,13 @@ func toRouterDeployment(serviceName string, app *v1.AppInstance, exposedPorts []
 		},
 	}
 
-	containerNames := map[string]bool{}
+	containerNames := map[string]struct{}{}
 	for _, portSpec := range exposedPorts {
 		name := fmt.Sprintf("port-%d", portSpec.Port.TargetPort)
-		if containerNames[name] {
+		if _, ok := containerNames[name]; ok {
 			continue
 		}
-		containerNames[name] = true
+		containerNames[name] = struct{}{}
 
 		ds.Spec.Template.Spec.Containers = append(ds.Spec.Template.Spec.Containers, corev1.Container{
 			Name:    name,
@@ -189,6 +190,26 @@ func toService(cfg *apiv1.Config, serviceName string, app *v1.AppInstance, svc *
 	return result
 }
 
+func ToPodDisruptionBudget(dep *appsv1.Deployment) *policyv1.PodDisruptionBudget {
+	var maxUnavailable intstr.IntOrString
+	if dep.Spec.Replicas == nil {
+		maxUnavailable = intstr.FromString("25%")
+	} else if *dep.Spec.Replicas > 2 {
+		maxUnavailable = intstr.FromInt(int(*dep.Spec.Replicas-1) / 2)
+	} else {
+		// Replicas is 0 (app stopped) or 1
+		maxUnavailable = intstr.FromInt(1)
+	}
+
+	return &policyv1.PodDisruptionBudget{
+		ObjectMeta: dep.ObjectMeta,
+		Spec: policyv1.PodDisruptionBudgetSpec{
+			Selector:       dep.Spec.Selector,
+			MaxUnavailable: &maxUnavailable,
+		},
+	}
+}
+
 func clusterIPsForService(cfg *apiv1.Config, req router.Request, namespace, serviceName string) ([]string, error) {
 	var service corev1.Service
 	err := req.Get(&service, namespace, serviceName)
