@@ -74,7 +74,7 @@ func TestParseProject(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			gotServer, gotAccount, gotNamespace, err := ParseProject(tt.args.project, nil)
+			gotServer, gotAccount, gotNamespace, _, err := ParseProject(tt.args.project, nil)
 			if (err != nil) != tt.wantErr {
 				t.Errorf("ParseProject() error = %v, wantErr %v", err, tt.wantErr)
 				return
