@@ -1,5 +1,11 @@
 package tables
 
+import (
+	"fmt"
+
+	"github.com/acorn-io/acorn/pkg/labels"
+)
+
 var (
 	CheckResult = [][]string{
 		{"Name", "Name"},
@@ -23,20 +29,33 @@ var (
 		{"App-Name", "Status.AppName"},
 		{"Bound-Volume", "Status.VolumeName"},
 		{"Capacity", "Spec.Capacity"},
+		{"Volume-Class", fmt.Sprintf("{{ index .Labels %q }}", labels.AcornVolumeClass)},
 		{"Status", "Status.Status"},
 		{"Access-Modes", "Status.Columns.AccessModes"},
 		{"Created", "{{ago .CreationTimestamp}}"},
 	}
 	VolumeConverter = MustConverter(Volume)
 
-	//Used for acorn image related printing
+	VolumeClass = [][]string{
+		{"Name", "{{ . | name }}"},
+		{"Default", "{{ boolToStar .Default }}"},
+		{"Inactive", "{{ boolToStar .Inactive }}"},
+		{"Storage-Class", "{{ .StorageClassName }}"},
+		{"Size-Range", "{{ displayRange .Size.Min .Size.Max }}"},
+		{"Default-Size", "{{ .Size.Default }}"},
+		{"Access-Modes", "{{ pointer .AllowedAccessModes }}"},
+		{"Description", "{{ .Description }}"},
+	}
+	VolumeClassConverter = MustConverter(VolumeClass)
+
+	// Used for acorn image related printing
 	ImageAcorn = [][]string{
 		{"Repository", "{{if eq .Repository \"\"}}<none>{{else}}{{.Repository}}{{end}}"},
 		{"Tag", "{{if eq .Tag \"\"}}<none>{{else}}{{.Tag}}{{end}}"},
 		{"Image-ID", "{{trunc .Name}}"},
 	}
 
-	//Used for kubectl image related printing
+	// Used for kubectl image related printing
 	Image = [][]string{
 		{"Image-ID", "{{trunc .Name}}"},
 		{"Tags", "{{if .Tags}}{{else}}<none>{{end}}{{range $index, $v := .Tags}}{{if $index}},{{end}}{{if eq $v \"\"}}<none>{{else}}{{$v}}{{end}}{{end}}"},
@@ -97,6 +116,15 @@ var (
 	}
 	BuilderConverter = MustConverter(Builder)
 
+	ComputeClass = [][]string{
+		{"Name", "Name"},
+		{"Default", "{{ boolToStar .Default }}"},
+		{"Memory Range", "{{ memoryToRange .Memory }}"},
+		{"Memory Default", "{{ defaultMemory .Memory }}"},
+		{"Description", "Description"},
+	}
+	ComputeClassConverter = MustConverter(ComputeClass)
+
 	Build = [][]string{
 		{"Name", "Name"},
 		{"Image", "Status.AppImage.ID"},
@@ -113,7 +141,6 @@ var (
 	ProjectClient = [][]string{
 		{"Name", "Name"},
 		{"Default", "{{ boolToStar .Default }}"},
-		{"Description", "Description"},
 	}
 
 	RuleRequests = [][]string{
